==> mono_6.8.0.105+dfsg.orig.tar.xz: mono-6.8.0.105+dfsg/external/binary-reference-assemblies/src/v4.6.1/Facades/System.Runtime.Extensions.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.

[assembly:System.Reflection.AssemblyVersionAttribute("4.0.10.0")]
[assembly:System.Diagnostics.DebuggableAttribute((System.Diagnostics.DebuggableAttribute.DebuggingModes)(2))]
[assembly:System.Reflection.AssemblyCompanyAttribute("Xamarin, Inc.")]
[assembly:System.Reflection.AssemblyCopyrightAttribute("Copyright (c) 2013 Xamarin Inc. (http://www.xamarin.com)")]
[assembly:System.Reflection.AssemblyDefaultAliasAttribute("System.Runtime.Extensions.dll")]
[assembly:System.Reflection.AssemblyDescriptionAttribute("System.Runtime.Extensions.dll")]
[assembly:System.Reflection.AssemblyFileVersionAttribute("4.0.0.0")]
[assembly:System.Reflection.AssemblyInformationalVersionAttribute("4.0.0.0")]
[assembly:System.Reflection.AssemblyProductAttribute("Mono Common Language Infrastructure")]
[assembly:System.Reflection.AssemblyTitleAttribute("System.Runtime.Extensions.dll")]
[assembly:System.Runtime.CompilerServices.CompilationRelaxationsAttribute(8)]
[assembly:System.Runtime.CompilerServices.ReferenceAssemblyAttribute]
[assembly:System.Runtime.CompilerServices.RuntimeCompatibilityAttribute(WrapNonExceptionThrows=true)]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.BitConverter))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Convert))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Diagnostics.Stopwatch))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Environment))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.IO.Path))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Math))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.MidpointRounding))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Net.WebUtility))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Progress<>))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Random))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Runtime.Versioning.FrameworkName))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.StringComparer))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.UriBuilder))]

==> mono_6.12.0.199+dfsg.orig.tar.xz: mono-6.12.0.199+dfsg/external/binary-reference-assemblies/src/v4.7.2/Facades/System.Runtime.Extensions.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.

[assembly:System.Reflection.AssemblyVersionAttribute("4.1.2.0")]
[assembly:System.Reflection.AssemblyCompanyAttribute("Mono development team")]
[assembly:System.Reflection.AssemblyCopyrightAttribute("(c) Various Mono authors")]
[assembly:System.Reflection.AssemblyDefaultAliasAttribute("System.Runtime.Extensions")]
[assembly:System.Reflection.AssemblyDescriptionAttribute("System.Runtime.Extensions")]
[assembly:System.Reflection.AssemblyFileVersionAttribute("4.7.3062.0")]
[assembly:System.Reflection.AssemblyInformationalVersionAttribute("4.7.3062.0")]
[assembly:System.Reflection.AssemblyMetadataAttribute("", "")]
[assembly:System.Reflection.AssemblyProductAttribute("Mono Common Language Infrastructure")]
[assembly:System.Reflection.AssemblyTitleAttribute("System.Runtime.Extensions")]
[assembly:System.Runtime.CompilerServices.ReferenceAssemblyAttribute]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.BitConverter))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Convert))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Diagnostics.Stopwatch))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Environment))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.IO.Path))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Math))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.MidpointRounding))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Net.WebUtility))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Progress<>))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Random))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.Runtime.Versioning.FrameworkName))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.StringComparer))]
[assembly:System.Runtime.CompilerServices.TypeForwardedToAttribute(typeof(System.UriBuilder))]
